import React, { useState } from "react";
import {
  Box,
  Typography,
  IconButton,
  Dialog,
  DialogContent,
} from "@mui/material";
import Grid from '@mui/material/Grid2';

const ImageView = () => {
  const [previewImage, setPreviewImage] = useState("https://business.aducktive.com/storage/product/23/ceGt6VWGAdW0tVUArAAkpAwk4DUu6QdGA95udBQK.webp"); // Initial preview image
  const [isZoomed, setIsZoomed] = useState(false);

  const thumbnails = [
    "https://business.aducktive.com/storage/product/23/ceGt6VWGAdW0tVUArAAkpAwk4DUu6QdGA95udBQK.webp",
    "https://business.aducktive.com/storage/product/24/z6wjsGoGb5X5F72TIW9JihYQR3ZnwEHFgcnfOCOF.webp",
    "https://business.aducktive.com/storage/product/22/JtniBtfevbtO9iJy3LUozgyGGe2HLv2rVNZ7C16e.webp",
    "https://business.aducktive.com/storage/product/25/GTyY9k0PvQUuC4cq5rUNgbIAw6H4vR6S5Ht3PSYn.webp",
  ];

  const handleThumbnailClick = (image) => {
    setPreviewImage(image);
  };

  const handleZoomToggle = () => {
    setIsZoomed(!isZoomed);
  };

  return (
    <Box sx={{ flexGrow: 1 }}>
      <Grid container spacing={2}>
        {/* Image Preview Section */}
        <Grid item size={12}>
          <Box
            sx={{
              overflow: "hidden",
              cursor: "pointer",
            }}
            onClick={handleZoomToggle}
          >
            <img
              src={previewImage}
              alt="Preview"
              style={{
                width: "100%",
                height: "auto",
                display: "block",
              }}
            />
          </Box>
        </Grid>

        {/* Image Control Section */}
        <Grid item size={12}>
          <Box
            sx={{
              display: "flex",
              flexDirection: "row",
              justifyContent:"center",
              padding: 2,
              gap:2
            }}
          >
            {thumbnails.map((thumbnail, index) => (
              <IconButton
                key={index}
                onClick={() => handleThumbnailClick(thumbnail)}
                sx={{
                  borderRadius: 2,
                  overflow: "hidden",
                }}
              >
                <img
                  src={thumbnail}
                  alt={`Thumbnail ${index + 1}`}
                  style={{
                    width: "100%",
                    height: "auto",
                    maxWidth: "75px",
                  }}
                />
              </IconButton>
            ))}
          </Box>
        </Grid>

      </Grid>

      {/* Zoom Dialog */}
      <Dialog open={isZoomed} onClose={handleZoomToggle} maxWidth="lg">
        <DialogContent>
          <img
            src={previewImage}
            alt="Zoomed Preview"
            style={{
              width: "100%",
              height: "auto",
            }}
          />
        </DialogContent>
      </Dialog>
    </Box>
  );
};

export default ImageView;
